@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
 """Define isbntools version and support IDs."""
 
-__version__ = '4.3.25'
-__support__ = 'py27, py35, py36, py37, py38'
+__version__ = '4.3.27'
+__support__ = 'py27, py35, py36, py37, py38, py39'
